Index: webrtc/p2p/base/packettransportinternal.h |
diff --git a/webrtc/p2p/base/packettransportinternal.h b/webrtc/p2p/base/packettransportinternal.h |
index 5789c62eeacaec610afc088475336e37c1c4efad..2c9d86d9ee8b783725f15a122308af653a5325e7 100644 |
--- a/webrtc/p2p/base/packettransportinternal.h |
+++ b/webrtc/p2p/base/packettransportinternal.h |
@@ -1,5 +1,5 @@ |
/* |
- * Copyright 2016 The WebRTC Project Authors. All rights reserved. |
+ * Copyright 2017 The WebRTC Project Authors. All rights reserved. |
* |
* Use of this source code is governed by a BSD-style license |
* that can be found in the LICENSE file in the root of the source |
@@ -14,6 +14,7 @@ |
#include <string> |
#include <vector> |
+#include "webrtc/api/ortc/packettransportinterface.h" |
// This is included for PacketOptions. |
#include "webrtc/base/asyncpacketsocket.h" |
#include "webrtc/base/sigslot.h" |
@@ -28,10 +29,9 @@ struct PacketOptions; |
struct PacketTime; |
struct SentPacket; |
-class PacketTransportInternal : public sigslot::has_slots<> { |
+class PacketTransportInternal : public virtual webrtc::PacketTransportInterface, |
+ public sigslot::has_slots<> { |
public: |
- virtual ~PacketTransportInternal() {} |
- |
// Identify the object for logging and debug purpose. |
virtual std::string debug_name() const = 0; |
@@ -59,7 +59,7 @@ class PacketTransportInternal : public sigslot::has_slots<> { |
// supported by all transport types. |
virtual int SetOption(rtc::Socket::Option opt, int value) = 0; |
// TODO(pthatcher): Once Chrome's MockPacketTransportInternal implements |
// this, remove the default implementation. |
virtual bool GetOption(rtc::Socket::Option opt, int* value) { return false; } |
@@ -90,6 +90,9 @@ class PacketTransportInternal : public sigslot::has_slots<> { |
// Signalled each time a packet is sent on this channel. |
sigslot::signal2<PacketTransportInternal*, const rtc::SentPacket&> |
SignalSentPacket; |
+ |
+ protected: |
+ PacketTransportInternal* GetInternal() override { return this; } |
}; |
} // namespace rtc |
@@ -59,7 +59,7 @@ class PacketTransportInternal : public sigslot::has_slots<> { |
// supported by all transport types. |
virtual int SetOption(rtc::Socket::Option opt, int value) = 0; |
- // TODO(pthatcher): Once Chrome's MockPacketTransportInternal implements |
+ // TODO(pthatcher): Once Chrome's MockPacketTransportInterface implements |
// this, remove the default implementation. |
virtual bool GetOption(rtc::Socket::Option opt, int* value) { return false; } |